# Jabutiles

A procedural tileset interface for games.

![Jabutiles Logo](https://github.com/ArthurBohn95/jabutiles/blob/main/examples/logo/imgs/logo.png?raw=true)

<br>

Provides support for orthogonal, isometric and hexagonal tiles.

Most of the backend is `pillow` (a PIL fork), the rest is `numpy`.

<br>

Install with: `pip install jabutiles`

[PyPI release](https://pypi.org/project/jabutiles/) 

[Documentation](https://github.com/ArthurBohn95/jabutiles/blob/main/docs/)

<br>

Trivia: the name comes from merging the words "jabuti" and "tiles":
- "jabuti" meaning "tortoise" in Portuguese;
- "tiles" coming from the stacked scutes on the back of their shells;
